@@ -10,7 +10,7 @@ from phylogenie.generators import (
     FBDTreeDatasetGenerator,
     TreeDatasetGeneratorConfig,
 )
-from phylogenie.io import load_fasta, load_newick
+from phylogenie.io import dump_newick, load_fasta, load_newick
 from phylogenie.msa import MSA
 from phylogenie.skyline import (
     SkylineMatrix,
@@ -26,11 +26,21 @@ from phylogenie.skyline import (
 )
 from phylogenie.tree import Tree
 from phylogenie.treesimulator import (
+    Birth,
+    BirthWithContactTracing,
+    Death,
     Event,
+    Migration,
+    Mutation,
+    MutationTargetType,
+    Sampling,
+    SamplingWithContactTracing,
+    generate_trees,
     get_BD_events,
     get_BDEI_events,
     get_BDSS_events,
     get_canonical_events,
+    get_contact_tracing_events,
     get_epidemiological_events,
     get_FBD_events,
     simulate_tree,
@@ -58,14 +68,25 @@ __all__ = [
     "skyline_vector",
     "Tree",
     "TreeDatasetGeneratorConfig",
+    "Birth",
+    "BirthWithContactTracing",
+    "Death",
     "Event",
+    "Migration",
+    "Mutation",
+    "MutationTargetType",
+    "Sampling",
+    "SamplingWithContactTracing",
     "get_BD_events",
     "get_BDEI_events",
     "get_BDSS_events",
     "get_canonical_events",
+    "get_contact_tracing_events",
     "get_epidemiological_events",
     "get_FBD_events",
+    "generate_trees",
     "simulate_tree",
+    "dump_newick",
     "load_fasta",
     "load_newick",
     "MSA",
